@@ -32,7 +32,13 @@ class ToVhdl2008Expr(ToHdlCommon):
         HdlOpType.XOR: " XOR ",
         HdlOpType.XNOR: " XNOR ",
         HdlOpType.EQ: ' = ',
-        HdlOpType.NEQ: " /= ",
+        HdlOpType.NE: " /= ",
+        HdlOpType.EQ_MATCH: ' ?= ',
+        HdlOpType.NE_MATCH: ' ?/= ',
+        HdlOpType.LT_MATCH: ' ?< ',
+        HdlOpType.LE_MATCH: ' ?<= ',
+        HdlOpType.GT_MATCH: ' ?> ',
+        HdlOpType.GE_MATCH: ' ?>= ',
         HdlOpType.TO: " TO ",
         HdlOpType.DOWNTO: " DOWNTO ",
         HdlOpType.ARROW: " => ",
@@ -85,11 +91,17 @@ class ToVhdl2008Expr(ToHdlCommon):
         HdlOpType.ROR: (6, L),
 
         HdlOpType.EQ:  (7, L),
-        HdlOpType.NEQ: (7, L),
+        HdlOpType.NE: (7, L),
         HdlOpType.GT:  (7, L),
         HdlOpType.LT:  (7, L),
         HdlOpType.GE:  (7, L),
         HdlOpType.LE:  (7, L),
+        HdlOpType.EQ_MATCH: (7, L),
+        HdlOpType.NE_MATCH: (7, L),
+        HdlOpType.LT_MATCH: (7, L),
+        HdlOpType.LE_MATCH: (7, L),
+        HdlOpType.GT_MATCH: (7, L),
+        HdlOpType.GE_MATCH: (7, L),
 
         HdlOpType.AND:  (8, L),
         HdlOpType.OR:   (8, L),
